.. :changelog:

=======
History
=======

0.2.1 (2015-12-03)
------------------

* Improve and document programmatic access

0.2.0 (2015-12-03)
------------------

* Much improved test coverage and refactored codebase
* Added --destination-path parameter

0.1.0 (2015-11-23)
------------------

* First release on PyPI
